package com.zcloud.personnel.positioning.command.convertor;

import com.zcloud.personnel.positioning.dto.clientobject.AlarmRuleCO;
import com.zcloud.personnel.positioning.dto.clientobject.AlarmRuleCompanyStatCO;
import com.zcloud.personnel.positioning.dto.clientobject.OptionCO;
import com.zcloud.personnel.positioning.persistence.dataobject.AlarmRuleCompanyStatDO;
import com.zcloud.personnel.positioning.persistence.dataobject.AlarmRuleDO;
import com.zcloud.personnel.positioning.persistence.dataobject.CompanyOptionDO;
import org.mapstruct.Mapper;

import java.util.List;

/**
 * web-app
 *
 * @Author fangjiakai
 * @Date 2026-07-07
 */
@Mapper(componentModel = "spring")
public interface AlarmRuleCoConvertor {
    AlarmRuleCO converDOToCO(AlarmRuleDO alarmRuleDO);

    List<AlarmRuleCO> converDOsToCOs(List<AlarmRuleDO> alarmRuleDOs);

    List<AlarmRuleCompanyStatCO> converCompanyStatDOsToCOs(List<AlarmRuleCompanyStatDO> dataObjects);

    List<OptionCO> converCompanyOptionDOsToCOs(List<CompanyOptionDO> dataObjects);
}
